@@ -36,6 +36,8 @@ def concat_spark_columns(data, name='concat_column', sep='|', return_data=False)
 
 	@f.udf(StringType())
 	def _to_string(x):
+		if x is None:
+			return 'NONE'
 		if isinstance(x, SparkRow):
 			x = x.asDict(recursive=True)
 		return x if isinstance(x, str) else str(x).lower()
@@ -101,8 +103,8 @@ def concat_pandas_columns(data, name='concat_column', sep='|', return_data=False
 	"""
 	def concat_row(x):
 		return sep.join([
-			value if isinstance(value, str) else str(value).lower()
-			for value in x.values if value is not None
+			'NONE' if value is None else (value if isinstance(value, str) else str(value).lower())
+			for value in x.values
 		])
 
 	data = data.copy()
